<?php

namespace Assetdocs\Assetsrequest\Providers;

use Illuminate\Support\ServiceProvider;

class AssetsrequestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'assetsrequest');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'assetsrequest');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('assetsrequest', function ($app) {
            return $this->app->make('Assetdocs\Assetsrequest\Assetsrequest');
        });

// Bind Assetreqhd to repository
        $this->app->bind(
            \Assetdocs\Assetsrequest\Interfaces\AssetreqhdRepositoryInterface::class,
            \Assetdocs\Assetsrequest\Repositories\Eloquent\AssetreqhdRepository::class
        );        // Bind Assetreqdtl to repository
        $this->app->bind(
            \Assetdocs\Assetsrequest\Interfaces\AssetreqdtlRepositoryInterface::class,
            \Assetdocs\Assetsrequest\Repositories\Eloquent\AssetreqdtlRepository::class
        );

        $this->app->register(\Assetdocs\Assetsrequest\Providers\AuthServiceProvider::class);
        $this->app->register(\Assetdocs\Assetsrequest\Providers\EventServiceProvider::class);
        $this->app->register(\Assetdocs\Assetsrequest\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['assetsrequest'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/assetsrequest.php')], 'config');

        // Publish view files
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/assetsrequest')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/assetsrequest')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public folder.
        $this->publishes([__DIR__ . '/../../../../public' => public_path('/')], 'public');
    }
}
